@@ -69,6 +69,8 @@
 #' When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
 #' `terms` (the selectors or variables selected), `value` and `component` is
 #' returned.
+#'  
+#' @template case-weights-supervised
 #'
 #' @references
 #' Micci-Barreca D (2001) "A preprocessing scheme for
@@ -126,13 +128,15 @@ step_lencode_bayes <-
         verbose = verbose,
         mapping = mapping,
         skip = skip,
-        id = id
+        id = id,
+        case_weights = NULL
       )
     )
   }
 
 step_lencode_bayes_new <-
-  function(terms, role, trained, outcome, options, verbose, mapping, skip, id) {
+  function(terms, role, trained, outcome, options, verbose, mapping, skip, id,
+           case_weights) {
     step(
       subclass = "lencode_bayes",
       terms = terms,
@@ -143,7 +147,8 @@ step_lencode_bayes_new <-
       verbose = verbose,
       mapping = mapping,
       skip = skip,
-      id = id
+      id = id,
+      case_weights = case_weights
     )
   }
 
@@ -151,13 +156,20 @@ step_lencode_bayes_new <-
 #' @export
 prep.step_lencode_bayes <- function(x, training, info = NULL, ...) {
   col_names <- recipes::recipes_eval_select(x$terms, training, info)
+  
+  wts <- recipes::get_case_weights(info, training)
+  were_weights_used <- recipes::are_weights_used(wts)
+  if (isFALSE(were_weights_used) || is.null(wts)) {
+    wts <- NULL
+  }
+  
   if (length(col_names) > 0) {
     check_type(training[, col_names], quant = FALSE)
     y_name <- recipes::recipes_eval_select(x$outcome, training, info)
     res <-
       map(training[, col_names], stan_coefs,
         y = training[, y_name],
-        x$options, x$verbose
+        x$options, x$verbose, wts
       )
   } else {
     res <- list()
@@ -172,11 +184,12 @@ prep.step_lencode_bayes <- function(x, training, info = NULL, ...) {
     verbose = x$verbose,
     mapping = res,
     skip = x$skip,
-    id = x$id
+    id = x$id,
+    case_weights = were_weights_used
   )
 }
 
-stan_coefs <- function(x, y, options, verbose, ...) {
+stan_coefs <- function(x, y, options, verbose, wts = NULL, ...) {
   rlang::check_installed("rstanarm")
   if (is.null(options$family)) {
     if (is.factor(y[[1]])) {
@@ -207,6 +220,9 @@ stan_coefs <- function(x, y, options, verbose, ...) {
   if (length(options) > 0) {
     args <- c(args, options)
   }
+  if (!is.null(wts)) {
+    args$weights <- as.double(wts)
+  }
 
   cl <- rlang::call2("stan_glmer", .ns = "rstanarm", !!!args)
 
@@ -233,6 +249,8 @@ stan_coefs <- function(x, y, options, verbose, ...) {
 
 #' @export
 bake.step_lencode_bayes <- function(object, new_data, ...) {
+  check_new_data(names(object$mapping), object, new_data)
+  
   for (col in names(object$mapping)) {
     new_data[, col] <- map_glm_coef(new_data[, col], object$mapping[[col]])
   }
@@ -245,7 +263,8 @@ bake.step_lencode_bayes <- function(object, new_data, ...) {
 print.step_lencode_bayes <-
   function(x, width = max(20, options()$width - 31), ...) {
     title <- "Linear embedding for factors via Bayesian GLM for "
-    print_step(names(x$mapping), x$terms, x$trained, title, width)
+    print_step(names(x$mapping), x$terms, x$trained, title, width,
+               case_weights = x$case_weights)
     invisible(x)
   }
 
