@@ -49,6 +49,8 @@
 #'
 #' When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
 #' `terms` (the columns that is selected), `values` is returned.
+#' 
+#' @template case-weights-supervised
 #'
 #' @examples
 #' library(modeldata)
@@ -103,14 +105,15 @@ step_discretize_cart <-
         min_n = min_n,
         rules = rules,
         skip = skip,
-        id = id
+        id = id,
+        case_weights = NULL
       )
     )
   }
 
 step_discretize_cart_new <-
   function(terms, role, trained, outcome, cost_complexity, tree_depth,
-           min_n, rules, skip, id) {
+           min_n, rules, skip, id, case_weights) {
     step(
       subclass = "discretize_cart",
       terms = terms,
@@ -122,18 +125,24 @@ step_discretize_cart_new <-
       min_n = min_n,
       rules = rules,
       skip = skip,
-      id = id
+      id = id,
+      case_weights = case_weights
     )
   }
 
 
-cart_binning <- function(predictor, term, outcome, cost_complexity, tree_depth, min_n) {
+cart_binning <- function(predictor, term, outcome, cost_complexity, tree_depth, 
+                         min_n, wts = NULL) {
   df <- data.frame(y = outcome, x = predictor)
+  if (is.null(wts)) {
+    wts <- rep(1, nrow(df))
+  }
   cart_mdl <-
     try(
       rpart::rpart(
         y ~ x,
         data = df,
+        weights = as.double(wts),
         cp  = cost_complexity,
         minsplit = min_n,
         maxdepth = tree_depth,
@@ -172,6 +181,12 @@ cart_binning <- function(predictor, term, outcome, cost_complexity, tree_depth,
 prep.step_discretize_cart <- function(x, training, info = NULL, ...) {
   col_names <- recipes::recipes_eval_select(x$terms, training, info)
 
+  wts <- recipes::get_case_weights(info, training)
+  were_weights_used <- recipes::are_weights_used(wts)
+  if (isFALSE(were_weights_used)) {
+    wts <- rep(1, nrow(training))
+  }
+  
   if (length(col_names) > 0) {
     check_type(training[, col_names])
 
@@ -187,7 +202,8 @@ prep.step_discretize_cart <- function(x, training, info = NULL, ...) {
         outcome = training[[y_name]],
         cost_complexity = x$cost_complexity,
         tree_depth = x$tree_depth,
-        min_n = x$min_n
+        min_n = x$min_n,
+        wts = wts
       )
 
     has_splits <- purrr::map_lgl(rules, ~ length(.x) > 0)
@@ -212,14 +228,16 @@ prep.step_discretize_cart <- function(x, training, info = NULL, ...) {
     min_n = x$min_n,
     rules = rules,
     skip = x$skip,
-    id = x$id
+    id = x$id,
+    case_weights = were_weights_used
   )
 }
 
 #' @export
 bake.step_discretize_cart <- function(object, new_data, ...) {
   vars <- object$rules
-
+  check_new_data(names(vars), object, new_data)
+  
   for (i in seq_along(vars)) {
     if (length(vars[[i]]) > 0) {
       var <- names(vars)[[i]]
@@ -237,13 +255,14 @@ bake.step_discretize_cart <- function(object, new_data, ...) {
       new_data <- binned_data
     }
   }
-  tibble::as_tibble(new_data)
+  new_data
 }
 
 #' @export
 print.step_discretize_cart <- function(x, width = max(20, options()$width - 30), ...) {
   title <- "Discretizing variables using CART "
-  print_step(names(x$rules), x$terms, x$trained, title, width)
+  print_step(names(x$rules), x$terms, x$trained, title, width,
+             case_weights = x$case_weights)
   invisible(x)
 }
 
