@@ -66,6 +66,8 @@
 #' When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
 #' `terms` (the selectors or variables selected), `value` and `component` is
 #' returned.
+#' 
+#' @template case-weights-supervised
 #'
 #' @references
 #' Micci-Barreca D (2001) "A preprocessing scheme for
@@ -112,13 +114,15 @@ step_lencode_mixed <-
         options = options,
         mapping = mapping,
         skip = skip,
-        id = id
+        id = id,
+        case_weights = NULL
       )
     )
   }
 
 step_lencode_mixed_new <-
-  function(terms, role, trained, outcome, options, mapping, skip, id) {
+  function(terms, role, trained, outcome, options, mapping, skip, id,
+           case_weights) {
     step(
       subclass = "lencode_mixed",
       terms = terms,
@@ -128,13 +132,21 @@ step_lencode_mixed_new <-
       options = options,
       mapping = mapping,
       skip = skip,
-      id = id
+      id = id,
+      case_weights = case_weights
     )
   }
 
 #' @export
 prep.step_lencode_mixed <- function(x, training, info = NULL, ...) {
   col_names <- recipes::recipes_eval_select(x$terms, training, info)
+  
+  wts <- recipes::get_case_weights(info, training)
+  were_weights_used <- recipes::are_weights_used(wts)
+  if (isFALSE(were_weights_used) || is.null(wts)) {
+    wts <- NULL
+  }
+  
   if (length(col_names) > 0) {
     check_type(training[, col_names], quant = FALSE)
     y_name <- recipes::recipes_eval_select(x$outcome, training, info)
@@ -149,6 +161,7 @@ prep.step_lencode_mixed <- function(x, training, info = NULL, ...) {
     res <-
       map(training[, col_names], lme_coefs,
         y = training[[y_name]],
+        wts = wts,
         x$options
       )
   } else {
@@ -162,24 +175,28 @@ prep.step_lencode_mixed <- function(x, training, info = NULL, ...) {
     options = x$options,
     mapping = res,
     skip = x$skip,
-    id = x$id
+    id = x$id,
+    case_weights = were_weights_used
   )
 }
 
-
-lme_coefs <- function(x, y, ...) {
+lme_coefs <- function(x, y, wts = NULL, ...) {
   rlang::check_installed("lme4")
   args <- list(
     formula = y ~ 1 + (1 | value),
     data = data.frame(value = x, y = y),
     na.action = na.omit
   )
-
+  
   dots <- list(...)
   if (length(dots) > 0) {
     args <- c(args, dots[[1]])
   }
   
+  if (!is.null(wts)) {
+    args$weights <- as.double(wts)
+  }
+  
   if (is.factor(y[[1]])) {
     args$data$y <- as.numeric(args$data$y) - 1
     if (is.null(args$family)) {
@@ -187,7 +204,12 @@ lme_coefs <- function(x, y, ...) {
     }
   }
   
-  cl <- rlang::call2("glmer", .ns = "lme4", !!!args)
+  if (is.null(args$family) || identical(args$family, gaussian)) {
+    cl <- rlang::call2("lmer", .ns = "lme4", !!!args)
+  } else {
+    cl <- rlang::call2("glmer", .ns = "lme4", !!!args)
+  }
+  
   mod <- rlang::eval_tidy(cl)
 
   coefs <- coef(mod)$value
@@ -223,6 +245,8 @@ map_lme_coef <- function(dat, mapping) {
 
 #' @export
 bake.step_lencode_mixed <- function(object, new_data, ...) {
+  check_new_data(names(object$mapping), object, new_data)
+  
   for (col in names(object$mapping)) {
     new_data[, col] <- map_lme_coef(new_data[, col], object$mapping[[col]])
   }
@@ -234,7 +258,8 @@ bake.step_lencode_mixed <- function(object, new_data, ...) {
 print.step_lencode_mixed <-
   function(x, width = max(20, options()$width - 31), ...) {
     title <- "Linear embedding for factors via mixed effects for "
-    print_step(names(x$mapping), x$terms, x$trained, title, width)
+    print_step(names(x$mapping), x$terms, x$trained, title, width,
+               case_weights = x$case_weights)
     invisible(x)
   }
 
